==> rendition-11.7.1.tgz: package/dist_esm5/extra/Form/captcha.js <==
import * as tslib_1 from "tslib";
import * as React from 'react';
import ReCaptcha from 'react-google-recaptcha';
import styled from 'styled-components';
var CenteredReCaptcha = styled(ReCaptcha)(templateObject_1 || (templateObject_1 = tslib_1.__makeTemplateObject(["\n\tdisplay: flex;\n\tjustify-content: center;\n\talign-items: center;\n\tmargin-bottom: 12px;\n"], ["\n\tdisplay: flex;\n\tjustify-content: center;\n\talign-items: center;\n\tmargin-bottom: 12px;\n"])));
var CaptchaWidget = (function (_super) {
    tslib_1.__extends(CaptchaWidget, _super);
    function CaptchaWidget(props) {
        var _this = _super.call(this, props) || this;
        _this.onChange = function () {
            var recaptchaValue = _this.recaptchaRef.current.getValue();
            _this.props.onChange(recaptchaValue);
        };
        _this.recaptchaRef = React.createRef();
        return _this;
    }
    CaptchaWidget.prototype.componentDidMount = function () {
        if (!window.RECAPTCHA_V2_API_KEY) {
            this.props.onChange('dummy');
        }
    };
    CaptchaWidget.prototype.componentWillReceiveProps = function (newProps) {
        if (newProps.value !== this.props.value && !Boolean(newProps.value)) {
            this.recaptchaRef.current.reset();
        }
    };
    CaptchaWidget.prototype.componentDidCatch = function (error) {
        console.error(error, 'The reCaptcha api key is invalid.');
    };
    CaptchaWidget.prototype.render = function () {
        var captchaKey = window.RECAPTCHA_V2_API_KEY;
        if (!captchaKey) {
            return null;
        }
        return (React.createElement(CenteredReCaptcha, { ref: this.recaptchaRef, onChange: this.onChange, sitekey: captchaKey }));
    };
    return CaptchaWidget;
}(React.Component));
export { CaptchaWidget };
var templateObject_1;

==> rendition-11.16.4.tgz: package/dist_esm5/extra/Form/captcha.js <==
import { __extends, __makeTemplateObject } from "tslib";
import * as React from 'react';
import ReCaptcha from 'react-google-recaptcha';
import styled from 'styled-components';
var CenteredReCaptcha = styled(ReCaptcha)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tdisplay: flex;\n\tjustify-content: center;\n\talign-items: center;\n\tmargin-bottom: 12px;\n"], ["\n\tdisplay: flex;\n\tjustify-content: center;\n\talign-items: center;\n\tmargin-bottom: 12px;\n"])));
var CaptchaWidget = (function (_super) {
    __extends(CaptchaWidget, _super);
    function CaptchaWidget(props) {
        var _this = _super.call(this, props) || this;
        _this.onChange = function () {
            var recaptchaValue = _this.recaptchaRef.current.getValue();
            _this.props.onChange(recaptchaValue);
        };
        _this.recaptchaRef = React.createRef();
        return _this;
    }
    CaptchaWidget.prototype.componentDidMount = function () {
        if (!window.RECAPTCHA_V2_API_KEY) {
            this.props.onChange('dummy');
        }
    };
    CaptchaWidget.prototype.componentWillReceiveProps = function (newProps) {
        if (newProps.value !== this.props.value && !Boolean(newProps.value)) {
            this.recaptchaRef.current.reset();
        }
    };
    CaptchaWidget.prototype.componentDidCatch = function (error) {
        console.error(error, 'The reCaptcha api key is invalid.');
    };
    CaptchaWidget.prototype.render = function () {
        var captchaKey = window.RECAPTCHA_V2_API_KEY;
        if (!captchaKey) {
            return null;
        }
        return (React.createElement(CenteredReCaptcha, { ref: this.recaptchaRef, onChange: this.onChange, sitekey: captchaKey }));
    };
    return CaptchaWidget;
}(React.Component));
export { CaptchaWidget };
var templateObject_1;
